==> aster-full-src-7.4.0-4.tar.gz: aster-src-7.4.0/setup.py <==
#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
# ==============================================================================
# COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ==============================================================================

# $Id: setup.py,v 1.23 2005/01/20 10:07:49 mcourtoi Exp $
# $Name:  $

import sys
# ----- check for Python version
if sys.hexversion < 0x020300F0:
   print _('This script requires Python 2.3 or higher, sorry !')
   sys.exit(4)

import os
import os.path
import time
import string
import re
import traceback
from types import ModuleType
from optparse import OptionParser

from as_setup import *
import products

# ----- differ messages translation
def _(mesg): return mesg

#-------------------------------------------------------------------------------
# 0. initialisation, configuration of the command-line parser
#-------------------------------------------------------------------------------
# 0.1. ----- list of products to install (could be skip through cfg)
to_install=['hdf5', 'med', 'tcl', 'tk',
            'Pmw', 'Numeric',
            'gmsh', 'gibi', 'homard', 'eficas',
            'astk', 'metis', 'aster', 'crpcrs']
# also available : astk_serv, aster_Linux

__aster_version__='STA7.4'

# 0.2. ----- version from cvs tag
__version__='VDEV'
# ----- CVS values
_mat=re.search('Id: setup.py,v ([_0-9\.]+)', '$Id: setup.py,v 1.23 2005/01/20 10:07:49 mcourtoi Exp $')
if _mat <> None:
   __version__=string.replace(_mat.group(1),'_','.')

__copyright__='Copyright (c) 2001-'+time.strftime('%Y')+ \
      ' EDF R&D - http://www.code-aster.org'

svers='Code_Aster Setup version '+__version__+'\n'+__copyright__

usage="usage: python %prog [options] action [arg]\n" + __copyright__ + \
_("""

Setup script for Code_Aster distribution.

NOTE : Code_Aster or eventually other products will be configured with
       the Python you use to run this setup :
         interpreter    : %(interp)s (version %(vers)s)
         prefix         : %(prefix)s

arguments :
  action must be one of 'install' or 'test'.

  By default all products are installed, but you can install only one (if a
  first attempt failed). Example : python setup.py install aster.
  
  Available products (the order is important) :
    %(prod)s.""") % {
   'vers' : sys.version[:3],
   'prefix' : os.path.abspath(sys.prefix),
   'interp' : sys.executable,
   'prod' : ', '.join(to_install),
}

_separ='\n' + '-'*80 + '\n'
_fmt_err=_(' *** Exception raised : %s')
_fmt_search=_('Checking for %s... ')

print _separ, svers, _separ

# 0.3. ----- command line parser
parser = OptionParser(
      usage=usage,
      version=svers,)
parser.add_option("--aster_root", dest="ASTER_ROOT", action='store',
#       default='/opt/aster',    not here !
      help=_("define toplevel directory for Code_Aster (default '/opt/aster')"), metavar="DIR")
parser.add_option("--sourcedir", dest="SOURCEDIR", action='store',
#       default='./SRC',         not here !
      help=_("directory which contains archive files (default './SRC')"),
      metavar="DIR")
parser.add_option("--cfg", dest="fcfg", action='store', metavar="FILE",
      help=_("file which contains the installation parameters"),)
parser.add_option("--noask", dest="noask", action='store_true',
      default=False,
      help=_("don't ask any questions"),)
parser.add_option("--nocache", dest="cache", action='store_false',
      default=True,
      help=_("delete cache file before starting (it's default if you do not specify a product name)"),)
parser.add_option("-q", "--quiet", dest="verbose", action='store_false',
      default=True,
      help=_("turn off verbose mode"),)
parser.add_option("-g", "--debug", dest="debug", action='store_true',
      default=False,
      help=_("turn on debug mode"),)

opts, args = parser.parse_args()
fcfg    = opts.fcfg
verbose = opts.verbose
debug   = opts.debug
noask   = opts.noask

default_cfgfile = 'setup.cfg'
cache_file      = 'setup.cache'

main=sys.argv[0]
def_opts={
   'ASTER_ROOT' : '/opt/aster',
   'SOURCEDIR'  : os.path.normpath(os.path.join(
      os.path.dirname(os.path.abspath(main)), 'SRC')),
}

# 0.4. ----- check for argument value
_install = False
_test    = False
if len(args)<1:
   parser.error(_(" 'action' keyword required"))
elif args[0]=='install':
   _install=True
elif args[0]=='test':
   _test=True
else:
   parser.error(_("unexpected argument %s") % repr(args[0]))

# 0.5. ----- adjust to_install list
to_install0=to_install+[]
if len(args)>1:
   bid=args.pop(0)
   for p in to_install+[]:
      if not p in args:
         to_install.remove(p)

# 0.6. ----- list of exceptions to handle during installation
if not debug:
   safe_exceptions=(SetupError,)
else:
   safe_exceptions=None

#-------------------------------------------------------------------------------
# 1. fill cfg reading setup.cfg + setup.cache files
#-------------------------------------------------------------------------------
cfg={}
cfg_init_keys=[]
# 1.1.1. ----- read parameters from 'fcfg'
if fcfg==None and os.path.isfile(default_cfgfile):
   fcfg=default_cfgfile
if fcfg<>None:
   fcfg=os.path.expanduser(fcfg)
   if not os.path.isfile(fcfg):
      print _('file not found %s') % fcfg
      sys.exit(4)
   else:
      print _separ,_('Reading config file %s...' % repr(fcfg))
      context={}
      try:
         execfile(fcfg, context)
      except:
         traceback.print_exc()
         print _separ,
         raise SetupError, _("reading '%s' failed (probably syntax" \
               " error occured, see traceback above)") % fcfg
      for k,v in context.items():
         if re.search('^__',k)==None and not type(v) is ModuleType:
            cfg[k]=v
            cfg_init_keys.append(k)

# 1.1.2. ----- read cache file
# delete it if --nocache or to_install list is full.
if (not opts.cache or to_install==to_install0) and os.path.exists(cache_file):
   print _separ,_('Deleting cache file %s...' % repr(cache_file))
   os.remove(cache_file)
if os.path.exists(cache_file):
   if fcfg<>None and os.stat(fcfg).st_ctime > os.stat(cache_file).st_ctime:
      print _separ, _(""" WARNING : %(cfg)s is newer than %(cache)s.
           The modifications you made in %(cfg)s might be inconsistent with
           cached values. If errors occur delete %(cache)s and restart at
           the beginning !""") \
         % { 'cfg' : repr(fcfg), 'cache' : repr(cache_file)}, _separ
   print _separ,_('Reading cache file %s...' % repr(cache_file))
   context={}
   try:
      execfile(cache_file, context)
   except:
      traceback.print_exc()
      print _separ,
      raise SetupError, _("reading '%s' failed (probably syntax" \
            " error occured)") % cache_file
   os.remove(cache_file)
   for k,v in context.items():
      if re.search('^__',k)==None and not type(v) is ModuleType:
         cfg[k]=v
         if not k in cfg_init_keys:
            cfg_init_keys.append(k)
         print _(' %15s (from cache) : %s' % (k, repr(v)))

# 1.1.3. ----- list of options to put in cfg
for o in ('ASTER_ROOT', 'SOURCEDIR',):
   if getattr(opts, o)<>None:
      cfg[o]=getattr(opts, o)
   elif not cfg.has_key(o):
      cfg[o]=def_opts[o]
   # if all options are not directories write a different loop
   cfg[o]=os.path.abspath(os.path.expanduser(cfg[o]))

# 1.2. ----- start a wizard
# ... later !

# 1.3.1. ----- configure standard directories
# {bin,lib,inc}dirs are used to search files
bindirs=['/usr/local/bin', '/usr/bin', '/bin',
         '/usr/X11R6/bin', '/usr/bin/X11', '/usr/openwin/bin',
         os.path.join(cfg['ASTER_ROOT'],'public','bin'),]
if cfg.get('BINDIR')<>None:
   bindirs=cfg['BINDIR']+bindirs

libdirs=['/usr/local/lib', '/usr/lib', '/lib',
         '/usr/X11R6/lib', '/usr/lib/X11', '/usr/openwin/lib',
         os.path.join(cfg['ASTER_ROOT'],'public','lib'),]
if cfg.get('LIBDIR')<>None:
   libdirs=cfg['LIBDIR']+libdirs

incdirs=['/usr/local/include', '/usr/include', '/include',
         '/usr/X11R6/include', '/usr/include/X11', '/usr/openwin/include',
         os.path.join(cfg['ASTER_ROOT'],'public','include'),]
if cfg.get('INCLUDEDIR')<>None:
   incdirs=cfg['INCLUDEDIR']+incdirs

# 1.3.2. ----- convert uname value to Code_Aster terminology...
if sys.platform == 'linux2':
   cfg['IFDEF']='P_LINUX'
elif sys.platform[:4] == 'osf1':
   cfg['IFDEF']='TRU64'
elif sys.platform == 'sunos5':
   cfg['IFDEF']='SOLARIS'
# elif sys.platform[:6] == 'irix64':
#    cfg['IFDEF']='IRIX64'
elif sys.platform[:4] == 'irix':
   cfg['IFDEF']='IRIX'
else:
    raise SetupError, "sys.platform=%s, os.name=%s" % \
          (sys.platform, os.name)
if cfg.get('_solaris64', False) and sys.platform == 'sunos5':
   cfg['IFDEF']='SOLARIS64'

# 1.3.3. ----- variables with predefined value
cfg['ASTER_VERSION']  =cfg.get('ASTER_VERSION', __aster_version__)

cfg['TOOLS_DIR']  =cfg.get('TOOLS_DIR', os.path.join(cfg['ASTER_ROOT'], 'outils'))
cfg['NODE']       =cfg.get('NODE', os.uname()[1].split('.')[0])
cfg['HOME_ASTK']  =cfg.get('HOME_ASTK', os.path.join(cfg['ASTER_ROOT'], 'ASTK'))
cfg['HOME_CRPCRS']=cfg.get('HOME_CRPCRS', os.path.join(cfg['TOOLS_DIR'],'CRPCRS'))

cfg['HOME_PYTHON']=cfg.get('HOME_PYTHON', os.path.abspath(sys.prefix))
cfg['PYTHON_EXE'] =cfg.get('PYTHON_EXE', sys.executable)
# these directories should respectively contain shared and static librairies
cfg['PYTHONLIB']  ='-L'+os.path.join(cfg['HOME_PYTHON'],'lib')+ \
   ' -L'+os.path.join(cfg['HOME_PYTHON'],'lib','python'+sys.version[:3],'config')+ \
   ' -lpython'+sys.version[:3]
cfg['SITE_PACKAGES']=os.path.join(cfg['HOME_PYTHON'],'lib',
                              'python'+sys.version[:3],'site-packages')

#-------------------------------------------------------------------------------
# 1.4. ----- auto-configuration
print _separ,

# 1.4.1. ----- checking for shell script interpreter
shell=find_file(['bash', 'ksh', 'zsh'], bindirs, [])
cfg['SHELL_EXECUTION']=cfg.get('SHELL_EXECUTION', shell)
if cfg['SHELL_EXECUTION']==None:
   del cfg['SHELL_EXECUTION']

# 1.4.2. ----- checking for maximum command line length (as configure do)
print _fmt_search % _('max command length'),
system=SYSTEM({ 'verbose' : True, 'debug' : False}, **{'maxcmdlen' : 2**31, })
default_value=1024
lenmax=0
i=0
teststr='ABCD'
iret=0
while iret==0:
   i+=1
   cmd='echo '+teststr
   iret, out = system.local_shell(cmd, verbose=False)
   out=out.replace('\n','')
   if len(out)<>len(teststr) or len(teststr)>2**16:
      lenmax=len(teststr)/2
      break
   teststr=teststr*2
# Add a significant safety factor because C++ compilers can tack on massive
# amounts of additional arguments before passing them to the linker.
# It appears as though 1/2 is a usable value.
system.MaxCmdLen=max(default_value, lenmax/2)
print system.MaxCmdLen
cfg['MAXCMDLEN']=system.MaxCmdLen
system.debug = debug

# 1.4.3. ----- check for xterm
xterm=find_file('xterm', bindirs, [])
cfg['XTERM']=cfg.get('XTERM', xterm)
if cfg['XTERM']==None:
   del cfg['XTERM']

# 1.4.4. ----- check for a text editor
# and modify command line of those which don't have a --display= option
ListEdit=[
   ['nedit' , 'nedit',],
   ['xemacs', 'xemacs -display @D',],
   ['emacs' , 'emacs -display @D',],
   ['xedit' , 'xedit -display @D',],
   ['vi'    , cfg.get('XTERM','xterm')+' -display @D -e vi',],]
for prg,cmd in ListEdit:
   edit=find_file(prg, bindirs, [])
   if edit<>None:
      edit=cmd.replace(prg, edit)
      break
cfg['EDITOR']=cfg.get('EDITOR', edit)
if cfg['EDITOR']==None:
   del cfg['EDITOR']

#-------------------------------------------------------------------------------
# 2. dependencies
#-------------------------------------------------------------------------------
# 2.1. ----- init a DEPENDENCIES instance with values set by __main__...
dep=DEPENDENCIES(
   cfg=cfg,
   cache=cache_file,
   set=[k for k in cfg.keys() if not k in cfg_init_keys],
   debug=debug,
   system=system,)

# 2.2. ----- ... and during configuration step
dep.Add(product='__cfg__',
   set=cfg_init_keys)
dep.FillCache()

#-------------------------------------------------------------------------------
# 3. products installation
#-------------------------------------------------------------------------------
summary=SUMMARY(to_install, system=system)

for product in to_install:
   if cfg.get('_install_'+product, product in to_install):
      t0=time.time()
      setup=None
      try:
         if hasattr(products, 'setup_%s' % product):
            setup=getattr(products, 'setup_%s' % product)(**{
               'dep'             : dep,
               'summary'         : summary,
               'verbose'         : verbose,
               'debug'           : debug,
               'test'            : _test,
               'bindirs'         : bindirs,
               'libdirs'         : libdirs,
               'incdirs'         : incdirs,
               'system'          : system,
            })
         else:
            raise StandardError, _('Setup script for %s not available.') % product
      except safe_exceptions, msg:
         print _fmt_err % msg
      dt=time.time()-t0
      summary.Set(product, setup, dt, sys.exc_info()[:2])

#-------------------------------------------------------------------------------
# 4. Summary
#-------------------------------------------------------------------------------
summary.Print()

==> aster-full-src-7.4.0-6.tar.gz: aster-src-7.4.0/setup.py <==
#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
# ==============================================================================
# COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ==============================================================================

# $Id: setup.py,v 1.26 2005/03/10 08:37:21 mcourtoi Exp $
# $Name:  $

# ----- differ messages translation
def _(mesg): return mesg

import sys
# ----- check for Python version
if sys.hexversion < 0x020300F0:
   print _('This script requires Python 2.3 or higher, sorry !')
   sys.exit(4)

import os
import os.path
import time
import string
import re
import traceback
from types import ModuleType
from optparse import OptionParser

from as_setup import *
import products

#-------------------------------------------------------------------------------
# 0. initialisation, configuration of the command-line parser
#-------------------------------------------------------------------------------
# 0.1. ----- list of products to install (could be skip through cfg)
to_install=['hdf5', 'med', 'tcl', 'tk',
            'Pmw', 'Numeric',
            'gmsh', 'gibi', 'homard', 'eficas',
            'astk', 'metis', 'aster', 'crpcrs']
# also available : astk_serv, aster_Linux

__aster_version__='STA7.4'

# 0.2. ----- version from cvs tag
__version__='VDEV'
# ----- CVS values
_mat=re.search('Id: setup.py,v ([_0-9\.]+)', '$Id: setup.py,v 1.26 2005/03/10 08:37:21 mcourtoi Exp $')
if _mat <> None:
   __version__=string.replace(_mat.group(1),'_','.')

__copyright__='Copyright (c) 2001-'+time.strftime('%Y')+ \
      ' EDF R&D - http://www.code-aster.org'

svers='Code_Aster Setup version '+__version__+'\n'+__copyright__

usage="usage: python %prog [options] action [arg]\n" + __copyright__ + \
_("""

Setup script for Code_Aster distribution.

NOTE : Code_Aster or eventually other products will be configured with
       the Python you use to run this setup :
         interpreter    : %(interp)s (version %(vers)s)
         prefix         : %(prefix)s

arguments :
  action must be one of 'install' or 'test'.

  By default all products are installed, but you can install only one (if a
  first attempt failed). Example : python setup.py install aster.
  
  Available products (the order is important) :
    %(prod)s.""") % {
   'vers' : sys.version[:3],
   'prefix' : os.path.abspath(sys.prefix),
   'interp' : sys.executable,
   'prod' : ', '.join(to_install),
}

_separ='\n' + '-'*80 + '\n'
_fmt_err=_(' *** Exception raised : %s')
_fmt_search=_('Checking for %s... ')

print _separ, svers, _separ

# 0.3. ----- command line parser
parser = OptionParser(
      usage=usage,
      version=svers,)
parser.add_option("--aster_root", dest="ASTER_ROOT", action='store',
#       default='/opt/aster',    not here !
      help=_("define toplevel directory for Code_Aster (default '/opt/aster')"), metavar="DIR")
parser.add_option("--sourcedir", dest="SOURCEDIR", action='store',
#       default='./SRC',         not here !
      help=_("directory which contains archive files (default './SRC')"),
      metavar="DIR")
parser.add_option("--cfg", dest="fcfg", action='store', metavar="FILE",
      help=_("file which contains the installation parameters"),)
parser.add_option("--noask", dest="noask", action='store_true',
      default=False,
      help=_("don't ask any questions"),)
parser.add_option("--nocache", dest="cache", action='store_false',
      default=True,
      help=_("delete cache file before starting (it's default if you do not specify a product name)"),)
parser.add_option("-q", "--quiet", dest="verbose", action='store_false',
      default=True,
      help=_("turn off verbose mode"),)
parser.add_option("-g", "--debug", dest="debug", action='store_true',
      default=False,
      help=_("turn on debug mode"),)

opts, args = parser.parse_args()
fcfg    = opts.fcfg
verbose = opts.verbose
debug   = opts.debug
noask   = opts.noask

default_cfgfile = 'setup.cfg'
cache_file      = 'setup.cache'

main=sys.argv[0]
def_opts={
   'ASTER_ROOT' : '/opt/aster',
   'SOURCEDIR'  : os.path.normpath(os.path.join(
      os.path.dirname(os.path.abspath(main)), 'SRC')),
}

# 0.4. ----- check for argument value
_install = False
_test    = False
if len(args)<1:
   parser.error(_(" 'action' keyword required"))
elif args[0]=='install':
   _install=True
elif args[0]=='test':
   _test=True
else:
   parser.error(_("unexpected argument %s") % repr(args[0]))

# 0.5. ----- adjust to_install list
to_install0=to_install+[]
if len(args)>1:
   bid=args.pop(0)
   for p in to_install+[]:
      if not p in args:
         to_install.remove(p)

# 0.6. ----- list of exceptions to handle during installation
if not debug:
   safe_exceptions=(SetupError,)
else:
   safe_exceptions=None

#-------------------------------------------------------------------------------
# 1. fill cfg reading setup.cfg + setup.cache files
#-------------------------------------------------------------------------------
cfg={}
cfg_init_keys=[]
# 1.1.1. ----- read parameters from 'fcfg'
if fcfg==None and os.path.isfile(default_cfgfile):
   fcfg=default_cfgfile
if fcfg<>None:
   fcfg=os.path.expanduser(fcfg)
   if not os.path.isfile(fcfg):
      print _('file not found %s') % fcfg
      sys.exit(4)
   else:
      print _separ,_('Reading config file %s...' % repr(fcfg))
      context={}
      try:
         execfile(fcfg, context)
      except:
         traceback.print_exc()
         print _separ,
         raise SetupError, _("reading '%s' failed (probably syntax" \
               " error occured, see traceback above)") % fcfg
      for k,v in context.items():
         if re.search('^__',k)==None and not type(v) is ModuleType:
            cfg[k]=v
            cfg_init_keys.append(k)

# 1.1.2. ----- read cache file
# delete it if --nocache or to_install list is full.
if (not opts.cache or to_install==to_install0) and os.path.exists(cache_file):
   print _separ,_('Deleting cache file %s...' % repr(cache_file))
   os.remove(cache_file)
if os.path.exists(cache_file):
   if fcfg<>None and os.stat(fcfg).st_ctime > os.stat(cache_file).st_ctime:
      print _separ, _(""" WARNING : %(cfg)s is newer than %(cache)s.
           The modifications you made in %(cfg)s might be inconsistent with
           cached values. If errors occur delete %(cache)s and restart at
           the beginning !""") \
         % { 'cfg' : repr(fcfg), 'cache' : repr(cache_file)}, _separ
   print _separ,_('Reading cache file %s...' % repr(cache_file))
   context={}
   try:
      execfile(cache_file, context)
   except:
      traceback.print_exc()
      print _separ,
      raise SetupError, _("reading '%s' failed (probably syntax" \
            " error occured)") % cache_file
   os.remove(cache_file)
   for k,v in context.items():
      if re.search('^__',k)==None and not type(v) is ModuleType:
         cfg[k]=v
         if not k in cfg_init_keys:
            cfg_init_keys.append(k)
         print _(' %15s (from cache) : %s' % (k, repr(v)))

# 1.1.3. ----- list of options to put in cfg
for o in ('ASTER_ROOT', 'SOURCEDIR',):
   if getattr(opts, o)<>None:
      cfg[o]=getattr(opts, o)
   elif not cfg.has_key(o):
      cfg[o]=def_opts[o]
   # if all options are not directories write a different loop
   cfg[o]=os.path.abspath(os.path.expanduser(cfg[o]))

# 1.2. ----- start a wizard
# ... later !

# 1.3.1. ----- configure standard directories
# {bin,lib,inc}dirs are used to search files
bindirs=['/usr/local/bin', '/usr/bin', '/bin',
         '/usr/X11R6/bin', '/usr/bin/X11', '/usr/openwin/bin',
         os.path.join(cfg['ASTER_ROOT'],'public','bin'),]
if cfg.get('BINDIR')<>None:
   bindirs=cfg['BINDIR']+bindirs

libdirs=['/usr/local/lib', '/usr/lib', '/lib',
         '/usr/X11R6/lib', '/usr/lib/X11', '/usr/openwin/lib',
         os.path.join(cfg['ASTER_ROOT'],'public','lib'),]
if cfg.get('LIBDIR')<>None:
   libdirs=cfg['LIBDIR']+libdirs

incdirs=['/usr/local/include', '/usr/include', '/include',
         '/usr/X11R6/include', '/usr/include/X11', '/usr/openwin/include',
         os.path.join(cfg['ASTER_ROOT'],'public','include'),]
if cfg.get('INCLUDEDIR')<>None:
   incdirs=cfg['INCLUDEDIR']+incdirs

# 1.3.2. ----- convert uname value to Code_Aster terminology...
if sys.platform == 'linux2':
   cfg['IFDEF']='P_LINUX'
elif sys.platform[:4] == 'osf1':
   cfg['IFDEF']='TRU64'
elif sys.platform == 'sunos5':
   cfg['IFDEF']='SOLARIS'
# elif sys.platform[:6] == 'irix64':
#    cfg['IFDEF']='IRIX64'
elif sys.platform[:4] == 'irix':
   cfg['IFDEF']='IRIX'
else:
    raise SetupError, "Unsupported platform : sys.platform=%s, os.name=%s" % \
          (sys.platform, os.name)
if cfg.get('_solaris64', False) and sys.platform == 'sunos5':
   cfg['IFDEF']='SOLARIS64'

# 1.3.3. ----- variables with predefined value
cfg['ASTER_VERSION']  =cfg.get('ASTER_VERSION', __aster_version__)

cfg['TOOLS_DIR']  =cfg.get('TOOLS_DIR', os.path.join(cfg['ASTER_ROOT'], 'outils'))
cfg['NODE']       =cfg.get('NODE', os.uname()[1].split('.')[0])
cfg['HOME_ASTK']  =cfg.get('HOME_ASTK', os.path.join(cfg['ASTER_ROOT'], 'ASTK'))
cfg['HOME_CRPCRS']=cfg.get('HOME_CRPCRS', os.path.join(cfg['TOOLS_DIR'],'CRPCRS'))

cfg['HOME_PYTHON']=cfg.get('HOME_PYTHON', os.path.abspath(sys.prefix))
cfg['PYTHON_EXE'] =cfg.get('PYTHON_EXE', sys.executable)
# these directories should respectively contain shared and static librairies
cfg['PYTHONLIB']  ='-L'+os.path.join(cfg['HOME_PYTHON'],'lib')+ \
   ' -L'+os.path.join(cfg['HOME_PYTHON'],'lib','python'+sys.version[:3],'config')+ \
   ' -lpython'+sys.version[:3]
cfg['SITE_PACKAGES']=os.path.join(cfg['HOME_PYTHON'],'lib',
                              'python'+sys.version[:3],'site-packages')

#-------------------------------------------------------------------------------
# 1.4. ----- auto-configuration
print _separ,

# 1.4.1. ----- checking for shell script interpreter
shell=find_file(['bash', 'ksh', 'zsh'], bindirs, [])
cfg['SHELL_EXECUTION']=cfg.get('SHELL_EXECUTION', shell)
if cfg['SHELL_EXECUTION']==None:
   del cfg['SHELL_EXECUTION']

# 1.4.2. ----- checking for maximum command line length (as configure do)
print _fmt_search % _('max command length'),
system=SYSTEM({ 'verbose' : True, 'debug' : False}, **{'maxcmdlen' : 2**31, })
default_value=1024
lenmax=0
i=0
teststr='ABCD'
iret=0
while iret==0:
   i+=1
   cmd='echo '+teststr
   iret, out = system.local_shell(cmd, verbose=False)
   out=out.replace('\n','')
   if len(out)<>len(teststr) or len(teststr)>2**16:
      lenmax=len(teststr)/2
      break
   teststr=teststr*2
# Add a significant safety factor because C++ compilers can tack on massive
# amounts of additional arguments before passing them to the linker.
# It appears as though 1/2 is a usable value.
system.MaxCmdLen=max(default_value, lenmax/2)
print system.MaxCmdLen
cfg['MAXCMDLEN']=system.MaxCmdLen
system.debug = debug

# 1.4.3. ----- check for xterm
xterm=find_file('xterm', bindirs, [])
cfg['XTERM']=cfg.get('XTERM', xterm)
if cfg['XTERM']==None:
   del cfg['XTERM']

# 1.4.4. ----- check for a text editor
# and modify command line of those which don't have a --display= option
ListEdit=[
   ['nedit' , 'nedit',],
   ['xemacs', 'xemacs -display @D',],
   ['emacs' , 'emacs -display @D',],
   ['xedit' , 'xedit -display @D',],
   ['vi'    , cfg.get('XTERM','xterm')+' -display @D -e vi',],]
for prg,cmd in ListEdit:
   edit=find_file(prg, bindirs, [])
   if edit<>None:
      edit=cmd.replace(prg, edit)
      break
cfg['EDITOR']=cfg.get('EDITOR', edit)
if cfg['EDITOR']==None:
   del cfg['EDITOR']

#-------------------------------------------------------------------------------
# 2. dependencies
#-------------------------------------------------------------------------------
# 2.1. ----- init a DEPENDENCIES instance with values set by __main__...
dep=DEPENDENCIES(
   cfg=cfg,
   cache=cache_file,
   set=[k for k in cfg.keys() if not k in cfg_init_keys],
   debug=debug,
   system=system,)

# 2.2. ----- ... and during configuration step
dep.Add(product='__cfg__',
   set=cfg_init_keys)
dep.FillCache()

#-------------------------------------------------------------------------------
# 3. products installation
#-------------------------------------------------------------------------------
summary=SUMMARY(to_install, system=system)

for product in to_install:
   if cfg.get('_install_'+product, product in to_install):
      t0=time.time()
      setup=None
      try:
         if hasattr(products, 'setup_%s' % product):
            setup=getattr(products, 'setup_%s' % product)(**{
               'dep'             : dep,
               'summary'         : summary,
               'verbose'         : verbose,
               'debug'           : debug,
               'test'            : _test,
               'bindirs'         : bindirs,
               'libdirs'         : libdirs,
               'incdirs'         : incdirs,
               'system'          : system,
            })
         else:
            raise StandardError, _('Setup script for %s not available.') % product
      except safe_exceptions, msg:
         print _fmt_err % msg
      dt=time.time()-t0
      summary.Set(product, setup, dt, sys.exc_info()[:2])

#-------------------------------------------------------------------------------
# 4. Summary
#-------------------------------------------------------------------------------
summary.Print()
